"""
betamax_matchers
================

See http://betamax.rtfd.org/ for documentation.

:copyright: (c) 2014 by Ian Cordasco
:license: Apache 2.0, see LICENSE for more details

"""

__author__ = 'Ian Cordasco'
__copyright__ = 'Copyright 2014-2016 Ian Cordasco'
__license__ = 'Apache 2.0'
__title__ = 'betamax_matchers'
__version__ = '0.4.0'
__version_info__ = tuple(int(i) for i in __version__.split('.'))
